import java.io.*;
import java.util.*;

public class TestGen {

    static int done = 0;

    static final Random rnd = new Random(556668949238L);

    static int rand(int n) {
        if (n < 1)
            return 0;
        return rnd.nextInt(n);
    }

    static final int MAXN = 1000;
    static final int MAXX = 1_000_000_000;

    static PrintWriter desc;

    static void print(int[] a) throws IOException {
        done++;
        System.err.println("Generation test #" + done);
        PrintWriter out;
        if (done < 10)
            out = new PrintWriter("../tests/0" + String.valueOf(done));
        else
            out = new PrintWriter("../tests/" + String.valueOf(done));
        out.println(a.length);
        for (int i = 0; i < a.length - 1; i++)
            out.print(a[i] + " ");
        out.println(a[a.length - 1]);
        out.close();
    }

    static String getPath() {
        if (done < 10)
            return "../tests/0" + String.valueOf(done);
        return "../tests/" + String.valueOf(done);
    }


    static void gen_samples() throws IOException {
        PrintWriter out;
        String path;
        path = "../preliminary/01";
        out = new PrintWriter(path);
        out.println("3");
        out.println("1 2 1");
        out.close();
        print_desc(path, "preliminary", "subtask0", 0, "sample 1");
        path = "../preliminary/02";
        out = new PrintWriter(path);
        out.println("2");
        out.println("2 2");
        out.close();
        print_desc(path, "preliminary", "subtask0", 0, "sample 2");
    }

    static void print_desc(String path, String folder, String subtask, int points, String comment) throws IOException {
        desc.println(String.format("%s, folder=%s, subtask=%s, points=%d, comment=\"%s\"", path, folder, subtask, points, comment));
    }

    static String subtask;

    static void print_desc_t(String comment) throws IOException {
        print_desc(getPath(), "tests", subtask, 0, comment);
    }

    //begin gens

    static void shuffle(int[] a) {
        for (int i = 0; i < a.length; i++) {
            int j = rnd.nextInt(a.length);
            int tmp = a[j];
            a[j] = a[i];
            a[i] = tmp;
        }
    }

    static void gen_equal1(int maxn) throws IOException {
        maxn -= maxn % 2;
        int[] a = new int[maxn];
        for (int i = 0; i < maxn / 2; i++)
            a[i] = 1;
        for (int i = maxn / 2; i < maxn; i++)
            a[i] = 2;
        shuffle(a);
        print(a);
        print_desc_t("odd number = even number");
    }

    static int rand_odd(int n) {
        return 2 * rand(n / 2) + 1;
    }

    static int rand_even(int n) {
        return 2 * rand(n / 2) + 2;
    }

    static void gen_equal2(int maxn, int maxx) throws IOException {
        maxn -= maxn % 2;
        int[] a = new int[maxn];
        for (int i = 0; i < maxn / 2; i++)
            a[i] = rand_odd(maxx);
        for (int i = maxn / 2; i < maxn; i++)
            a[i] = rand_even(maxx);
        shuffle(a);
        print(a);
        print_desc_t("odd number = even number");
    }

    static void gen_rand1(int maxn) throws IOException {
        int[] a = new int[maxn];
        for (int i = 0; i < maxn; i++)
            a[i] = rand(2) + 1;
        shuffle(a);
        print(a);
        print_desc_t("random test");
    }

    static void gen_rand2(int maxn, int maxx) throws IOException {
        int[] a = new int[maxn];
        for (int i = 0; i < maxn; i++)
            a[i] = rand(maxx) + 1;
        shuffle(a);
        print(a);
        print_desc_t("random test");
    }



    //end gens

    public static void main(String[] args) throws IOException {
        new File("../preliminary").mkdir();
        new File("../tests").mkdir();
        desc = new PrintWriter("../tests.desc");

        done = 0;
        gen_samples();

        subtask = "subtask1";

        for (int i = 0; i < 4; i++) {
            int n = rand(MAXN / 2) + MAXN / 2 + 1;
            gen_equal1(n);
            for (int j = 0; j < 4; j++) {
                n = rand(MAXN / 2) + MAXN / 2 + 1;
                gen_rand1(n);
            }
        }
        gen_equal1(MAXN);
        gen_rand1(MAXN);
        gen_rand1(MAXN);
        gen_rand1(MAXN);
        gen_rand1(MAXN);

        desc.println(String.format("comment_subtask%d=\"n &lt;= %d, a &lt;= %d\"", 1, MAXN, 2));
        desc.println(String.format("bonus_subtask%d=%d", 1, 50));

        subtask = "subtask2";

        for (int i = 0; i < 4; i++) {
            int n = rand(MAXN / 2) + MAXN / 2 + 1;
            gen_equal2(n, MAXX);
            for (int j = 0; j < 4; j++) {
                n = rand(MAXN / 2) + MAXN / 2 + 1;
                gen_rand2(n, MAXX);
            }
        }
        gen_equal2(MAXN, MAXX);
        gen_rand2(MAXN, MAXX);
        gen_rand2(MAXN, MAXX);
        gen_rand2(MAXN, MAXX);
        gen_rand2(MAXN, MAXX);

        desc.println(String.format("comment_subtask%d=\"n &lt;= %d, a &lt;= %d\"", 2, MAXN, MAXX));
        desc.println(String.format("bonus_subtask%d=%d", 2, 50));


        desc.close();
    }
}
